| Title: | Interactive Document for Working with Classification Tree Analysis |
|---|---|
| Description: | An interactive document on the topic of classification tree analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://kartikeyab.shinyapps.io/CTShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-13 09:51:47 UTC |
| Source: | https://github.com/cran/CTShiny |
CTShiny() loads interactive user interface built using R 'shiny'.
CTShiny()CTShiny()
Start CTShiny
The interactive user interface is to provide an easy way for classification tree analysis and downloading relevant plot.
Nothing
if(interactive()){ library(rmarkdown) CTShiny() }if(interactive()){ library(rmarkdown) CTShiny() }