Welcome to ClientVPS Mirrors

Help for package CTShiny
Type: Package
Title: Interactive Document for Working with Classification Tree Analysis
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: An interactive document on the topic of classification tree analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at https://kartikeyab.shinyapps.io/CTShiny/.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,rmarkdown,dplyr,datasets,caret,e1071,rhandsontable,rpart,rpart.plot,party
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2019-05-02 05:59:46 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2019-05-03 12:51:01 UTC

Launch 'CTShiny' Interface

Description

CTShiny() loads interactive user interface built using R 'shiny'.

Usage

CTShiny()

Details

Start CTShiny

The interactive user interface is to provide an easy way for classification tree analysis and downloading relevant plot.

Value

Nothing

Examples

if(interactive()){
library(rmarkdown)
CTShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.